import { jsx, jsxs, Fragment } from 'react/jsx-runtime';
import { createContext, useContext, useState } from 'react';

function ChevronDownSvg(props) {
    return (jsx("svg", Object.assign({}, props, { width: '16', height: '16', viewBox: '0 0 16 16', fill: 'none', xmlns: 'http://www.w3.org/2000/svg' }, { children: jsx("path", { d: 'M4 6L8 10L12 6', stroke: 'currentColor', strokeWidth: '1', strokeLinecap: 'round', strokeLinejoin: 'round' }) })));
}

const JsonViewContext = createContext({
    collapseStringsAfterLength: 99,
    collapseObjectsAfterLength: 20
});
function JsonView({ src, collapseStringsAfterLength = 99, collapseObjectsAfterLength = 20 }) {
    return (jsx(JsonViewContext.Provider, Object.assign({ value: { collapseStringsAfterLength, collapseObjectsAfterLength } }, { children: jsx("code", Object.assign({ className: 'json-view' }, { children: jsx(JsonNode, { node: src }) })) })));
}
function JsonNode({ node }) {
    if (Array.isArray(node) || isObject(node)) {
        return jsx(ObjectNode, { node: node });
    }
    else if (typeof node === 'number')
        return jsx("span", Object.assign({ className: 'json-view--number' }, { children: node }));
    else if (typeof node === 'string')
        return node.length > 12 ? jsx(LongString, { str: node }) : jsxs("span", Object.assign({ className: 'json-view--string' }, { children: ["\"", node, "\""] }));
    else if (typeof node === 'boolean')
        return jsx("span", Object.assign({ className: 'json-view--boolean' }, { children: String(node) }));
    else if (node === null)
        return jsx("span", Object.assign({ className: 'json-view--null' }, { children: "null" }));
    else
        return jsx("span", Object.assign({ className: 'json-view--string' }, { children: String(node) }));
}
function ObjectNode({ node }) {
    const jv = useContext(JsonViewContext);
    const [fold, setFold] = useState(Array.isArray(node) && node.length > jv.collapseObjectsAfterLength
        ? true
        : isObject(node) && Object.keys(node).length > jv.collapseObjectsAfterLength
            ? true
            : false);
    if (Array.isArray(node)) {
        return (jsxs(Fragment, { children: [jsx("span", { children: '[' }), !fold && jsx(ChevronDownSvg, { onClick: () => setFold(true), className: 'jv-chevron' }), !fold ? (jsx("div", Object.assign({ className: 'jv-indent' }, { children: node.map((n, i) => (jsx(NameValue, { name: i, value: n }, i))) }))) : (jsx("button", Object.assign({ onClick: () => setFold(false), className: 'jv-button' }, { children: "..." }))), jsx("span", { children: ']' })] }));
    }
    else if (isObject(node)) {
        return (jsxs(Fragment, { children: [jsx("span", { children: '{' }), !fold && jsx(ChevronDownSvg, { onClick: () => setFold(true), className: 'jv-chevron' }), !fold ? (jsx("div", Object.assign({ className: 'jv-indent' }, { children: Object.entries(node).map(([name, value]) => (jsx(NameValue, { name: name, value: value }, name))) }))) : (jsx("button", Object.assign({ onClick: () => setFold(false), className: 'jv-button' }, { children: "..." }))), jsx("span", { children: '}' })] }));
    }
    return null;
}
function LongString({ str }) {
    const jv = useContext(JsonViewContext);
    if (str.length < jv.collapseStringsAfterLength)
        return jsxs("span", Object.assign({ className: 'json-view--string' }, { children: ["\"", str, "\""] }));
    const [fold, setFold] = useState(true);
    return (jsxs("span", Object.assign({ onClick: () => setFold(!fold), className: 'json-view--string cursor-pointer' }, { children: ["\"", fold ? str.slice(0, 6) + '...' + str.slice(-4) : str, "\""] })));
}
function NameValue({ name, value }) {
    return (jsxs("div", { children: [jsx("span", Object.assign({ className: typeof name === 'number' ? 'json-view--index' : 'json-view--property' }, { children: name })), ":", ' ', jsx(JsonNode, { node: value })] }));
}
function isObject(node) {
    return Object.prototype.toString.call(node) === '[object Object]';
}

export { JsonView as default };
//# sourceMappingURL=index.mjs.map
